@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Help::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $App::DuckPAN::Help::VERSION = '0.042';
+  $App::DuckPAN::Help::VERSION = '0.043';
 }
 
 use Moo;
@@ -24,11 +24,6 @@ sub header { my $version = shift->version; return <<"__EOT__"; }
 __EOT__
 
 sub help { return shift->header().<<'__EOT__'; }
-=> You need an account at https://dukgo.com/
-
-duckpan setup
--------------
- Initialize your DuckPAN development environment
 
 duckpan check
 -------------
@@ -64,13 +59,3 @@ duckpan faq
 __EOT__
 
 1;
-
-sub goodie { return shift->header().<<'__EOT__'; }
-duckpan goodie new MyGoodie
-------------------------------------------------
- Starts a new goodie 'DDG::Goodie::MyGoodie' in 'p5-ddg-goodie-mygoodie'
- (may be renamed, will check if setup was run)
-
-__EOT__
-
-1;
