@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Perl::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $App::DuckPAN::Perl::VERSION = '0.042';
+  $App::DuckPAN::Perl::VERSION = '0.043';
 }
 
 use Moo;
@@ -51,7 +51,9 @@ sub get_local_version {
 	{
 		local $@;
 		eval {
-			$v = Module::Data->new( $module )->version;
+			my $m = Module::Data->new( $module );
+			$m->require;
+			$v = $m->version;
 			1
 		} or return;
 	};
